"""
backend_identity_index_entry automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union


# Represents a concrete identity class
class BackendIdentityIndexEntry(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    class_: Optional[str] = Field(default=None, alias="class")
    pass


