"""
backend_connection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .backend_connection_config import BackendConnectionConfig
from .common_metadata import CommonMetadata


# This object represents a connection to an external system like i.e. a database, message-queue or client-sdk
class BackendConnection(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    class_: Optional[str] = Field(default=None, alias="class")
    oauth_: Optional[bool] = Field(default=None, alias="oauth2")
    config: Optional[BackendConnectionConfig] = Field(default=None, alias="config")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass


