"""
consumer_user_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union


class ConsumerUserPlan(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    price: Optional[int] = Field(default=None, alias="price")
    points: Optional[int] = Field(default=None, alias="points")
    period: Optional[int] = Field(default=None, alias="period")
    pass


