"""
backend_action automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union
from .backend_action_config import BackendActionConfig
from .common_metadata import CommonMetadata


# This object represents the business logic which can be executed either through an operation or cronjob
class BackendAction(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    class_: Optional[str] = Field(default=None, alias="class")
    async_: Optional[bool] = Field(default=None, alias="async")
    config: Optional[BackendActionConfig] = Field(default=None, alias="config")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass


