"""
backend_backup_export automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union


# Export of the complete system configuration
class BackendBackupExport(BaseModel):
    export: Optional[str] = Field(default=None, alias="export")
    pass


